==> pmml-model-1.0.18-sources.jar: org/dmg/pmml/IntSparseArray.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlList;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import com.sun.xml.bind.Locatable;
import com.sun.xml.bind.annotation.XmlLocation;
import org.w3._2001.xmlschema.Adapter1;
import org.xml.sax.Locator;


/**
 * <p>Java class for INT-SparseArray element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="INT-SparseArray">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element ref="{http://www.dmg.org/PMML-4_1}Indices" minOccurs="0"/>
 *           &lt;element ref="{http://www.dmg.org/PMML-4_1}INT-Entries" minOccurs="0"/>
 *         &lt;/sequence>
 *         &lt;attribute name="n" type="{http://www.dmg.org/PMML-4_1}INT-NUMBER" />
 *         &lt;attribute name="defaultValue" type="{http://www.dmg.org/PMML-4_1}INT-NUMBER" default="0" />
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "indices",
    "entries"
})
@XmlRootElement(name = "INT-SparseArray")
public class IntSparseArray
    extends SparseArray
    implements Locatable
{

    @XmlList
    @XmlElement(name = "Indices", type = Integer.class)
    protected List<Integer> indices;
    @XmlList
    @XmlElement(name = "INT-Entries", type = Integer.class)
    protected List<Integer> entries;
    @XmlAttribute(name = "n")
    @XmlJavaTypeAdapter(Adapter1 .class)
    protected Integer n;
    @XmlAttribute(name = "defaultValue")
    @XmlJavaTypeAdapter(Adapter1 .class)
    protected Integer defaultValue;
    @XmlLocation
    @XmlTransient
    protected Locator locator;

    /**
     * Gets the value of the indices property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the indices property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getIndices().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Integer }
     * 
     * 
     */
    public List<Integer> getIndices() {
        if (indices == null) {
            indices = new ArrayList<Integer>();
        }
        return this.indices;
    }

    /**
     * Gets the value of the entries property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the entries property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getEntries().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Integer }
     * 
     * 
     */
    public List<Integer> getEntries() {
        if (entries == null) {
            entries = new ArrayList<Integer>();
        }
        return this.entries;
    }

    /**
     * Gets the value of the n property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public Integer getN() {
        return n;
    }

    /**
     * Sets the value of the n property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setN(Integer value) {
        this.n = value;
    }

    /**
     * Gets the value of the defaultValue property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public int getDefaultValue() {
        if (defaultValue == null) {
            return new Adapter1().unmarshal("0");
        } else {
            return defaultValue;
        }
    }

    /**
     * Sets the value of the defaultValue property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDefaultValue(Integer value) {
        this.defaultValue = value;
    }

    public Locator sourceLocation() {
        return locator;
    }

    public void setSourceLocation(Locator newLocator) {
        locator = newLocator;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-1.1.0-sources.jar: org/dmg/pmml/IntSparseArray.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlList;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import com.sun.xml.bind.Locatable;
import com.sun.xml.bind.annotation.XmlLocation;
import org.w3._2001.xmlschema.Adapter1;
import org.xml.sax.Locator;


/**
 * <p>Java class for INT-SparseArray element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="INT-SparseArray">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element ref="{http://www.dmg.org/PMML-4_1}Indices" minOccurs="0"/>
 *           &lt;element ref="{http://www.dmg.org/PMML-4_1}INT-Entries" minOccurs="0"/>
 *         &lt;/sequence>
 *         &lt;attribute name="n" type="{http://www.dmg.org/PMML-4_1}INT-NUMBER" />
 *         &lt;attribute name="defaultValue" type="{http://www.dmg.org/PMML-4_1}INT-NUMBER" default="0" />
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "indices",
    "entries"
})
@XmlRootElement(name = "INT-SparseArray")
public class IntSparseArray
    extends SparseArray
    implements Locatable
{

    @XmlList
    @XmlElement(name = "Indices", type = Integer.class)
    protected List<Integer> indices;
    @XmlList
    @XmlElement(name = "INT-Entries", type = Integer.class)
    protected List<Integer> entries;
    @XmlAttribute(name = "n")
    @XmlJavaTypeAdapter(Adapter1 .class)
    protected Integer n;
    @XmlAttribute(name = "defaultValue")
    @XmlJavaTypeAdapter(Adapter1 .class)
    protected Integer defaultValue;
    @XmlLocation
    @XmlTransient
    protected Locator locator;

    /**
     * Gets the value of the indices property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the indices property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getIndices().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Integer }
     * 
     * 
     */
    public List<Integer> getIndices() {
        if (indices == null) {
            indices = new ArrayList<Integer>();
        }
        return this.indices;
    }

    /**
     * Gets the value of the entries property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the entries property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getEntries().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Integer }
     * 
     * 
     */
    public List<Integer> getEntries() {
        if (entries == null) {
            entries = new ArrayList<Integer>();
        }
        return this.entries;
    }

    /**
     * Gets the value of the n property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public Integer getN() {
        return n;
    }

    /**
     * Sets the value of the n property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setN(Integer value) {
        this.n = value;
    }

    /**
     * Gets the value of the defaultValue property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public int getDefaultValue() {
        if (defaultValue == null) {
            return new Adapter1().unmarshal("0");
        } else {
            return defaultValue;
        }
    }

    /**
     * Sets the value of the defaultValue property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDefaultValue(Integer value) {
        this.defaultValue = value;
    }

    public IntSparseArray withIndices(Integer... values) {
        if (values!= null) {
            for (Integer value: values) {
                getIndices().add(value);
            }
        }
        return this;
    }

    public IntSparseArray withIndices(Collection<Integer> values) {
        if (values!= null) {
            getIndices().addAll(values);
        }
        return this;
    }

    public IntSparseArray withEntries(Integer... values) {
        if (values!= null) {
            for (Integer value: values) {
                getEntries().add(value);
            }
        }
        return this;
    }

    public IntSparseArray withEntries(Collection<Integer> values) {
        if (values!= null) {
            getEntries().addAll(values);
        }
        return this;
    }

    public IntSparseArray withN(Integer value) {
        setN(value);
        return this;
    }

    public IntSparseArray withDefaultValue(Integer value) {
        setDefaultValue(value);
        return this;
    }

    public Locator sourceLocation() {
        return locator;
    }

    public void setSourceLocation(Locator newLocator) {
        locator = newLocator;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}
